﻿using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;


using System.IO;
using System.Data;
using System.Configuration;
using System.Data.SqlClient;
using System.Drawing;
using iTextSharp.text;
using iTextSharp.text.pdf;
using iTextSharp.tool.xml;

public partial class CS : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!this.IsPostBack)
        {
            this.BindGrid();
        }
    }

    private void BindGrid()
    {
        string query = "SELECT * FROM tblFiles";
        string constr = ConfigurationManager.ConnectionStrings["constr"].ConnectionString;
        using (SqlConnection con = new SqlConnection(constr))
        {
            using (SqlDataAdapter sda = new SqlDataAdapter(query, con))
            {
                using (DataTable dt = new DataTable())
                {
                    sda.Fill(dt);
                    gvFiles.DataSource = dt;
                    gvFiles.DataBind();
                }
            }
        }
    }

    protected void OnRowDataBound(object sender, GridViewRowEventArgs e)
    {
        if (e.Row.RowType == DataControlRowType.DataRow)
        {
            //Fetch the Current URL.
            Uri uri = Request.Url;

            //Generate Absolute Path for the Images folder.
            string applicationUrl = string.Format("{0}://{1}{2}", uri.Scheme, uri.Authority, uri.AbsolutePath);
            applicationUrl = applicationUrl.Replace(Request.Url.Segments[Request.Url.Segments.Length - 1], "");

            //Fetch the Image ID from the DataKeyNames property.
            int id = Convert.ToInt32(gvFiles.DataKeys[e.Row.RowIndex].Values[0]);

            //Generate and set the Handler Absolute URL in the Image control.
            string imageUrl = string.Format("{0}HandlerCS.ashx?id={1}", applicationUrl, id);
            (e.Row.FindControl("Image1") as System.Web.UI.WebControls.Image).ImageUrl = imageUrl;
        }
    }

    protected void ExportToWord(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.doc");
        Response.Charset = "";
        Response.ContentType = "application/vnd.ms-word";
        using (StringWriter sw = new StringWriter())
        {
            HtmlTextWriter hw = new HtmlTextWriter(sw);

            //To Export all pages.
            gvFiles.AllowPaging = false;
            this.BindGrid();

            gvFiles.HeaderRow.BackColor = Color.White;
            foreach (TableCell cell in gvFiles.HeaderRow.Cells)
            {
                cell.BackColor = gvFiles.HeaderStyle.BackColor;
            }
            foreach (GridViewRow row in gvFiles.Rows)
            {
                row.BackColor = Color.White;
                foreach (TableCell cell in row.Cells)
                {
                    if (row.RowIndex % 2 == 0)
                    {
                        cell.BackColor = gvFiles.AlternatingRowStyle.BackColor;
                    }
                    else
                    {
                        cell.BackColor = gvFiles.RowStyle.BackColor;
                    }
                }
            }

            gvFiles.RenderControl(hw);

            Response.Output.Write(sw.ToString());
            Response.Flush();
            Response.End();
        }
    }

    protected void ExportToExcel(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.xls");
        Response.Charset = "";
        Response.ContentType = "application/vnd.ms-excel";
        using (StringWriter sw = new StringWriter())
        {
            HtmlTextWriter hw = new HtmlTextWriter(sw);

            //To Export all pages.
            gvFiles.AllowPaging = false;
            this.BindGrid();

            gvFiles.HeaderRow.BackColor = Color.White;
            foreach (TableCell cell in gvFiles.HeaderRow.Cells)
            {
                cell.BackColor = gvFiles.HeaderStyle.BackColor;
            }
            foreach (GridViewRow row in gvFiles.Rows)
            {
                row.BackColor = Color.White;
                foreach (TableCell cell in row.Cells)
                {
                    if (row.RowIndex % 2 == 0)
                    {
                        cell.BackColor = gvFiles.AlternatingRowStyle.BackColor;
                    }
                    else
                    {
                        cell.BackColor = gvFiles.RowStyle.BackColor;
                    }
                    cell.CssClass = "textmode";
                }
            }

            gvFiles.RenderControl(hw);

            //Style to format numbers to string.
            string style = @"<style> .textmode { mso-number-format:\@; } </style>";
            Response.Write(style);
            Response.Output.Write(sw.ToString());
            Response.Flush();
            Response.End();
        }
    }

    protected void ExportToPDF(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.pdf");
        Response.Charset = "";
        Response.ContentType = "application/pdf";

        //To Export all pages.
        gvFiles.AllowPaging = false;
        this.BindGrid();

        using (StringWriter sw = new StringWriter())
        {
            using (HtmlTextWriter hw = new HtmlTextWriter(sw))
            {
                gvFiles.RenderControl(hw);
                using (StringReader sr = new StringReader(sw.ToString()))
                {
                    using (Document pdfDoc = new Document(PageSize.A4, 10f, 10f, 10f, 0f))
                    {
                        using (PdfWriter writer = PdfWriter.GetInstance(pdfDoc, Response.OutputStream))
                        {
                            pdfDoc.Open();
                            XMLWorkerHelper.GetInstance().ParseXHtml(writer, pdfDoc, sr);
                            pdfDoc.Close();
                            Response.Cache.SetCacheability(HttpCacheability.NoCache);
                            Response.Write(pdfDoc);
                            Response.End();
                        }
                    }
                }
            }
        }
    }

    public override void VerifyRenderingInServerForm(Control control)
    {
        /* Verifies that the control is rendered. */
    }
}
